@@ -9,6 +9,15 @@
     kmg2SaveGraph  = 0,
     kmg2Theme      = 0
   )
+  
+  if (.Platform$OS.type == "windows") {
+    windowsFonts(
+      Japan1 = "Japan1", Japan1HeiMin = "Japan1HeiMin",
+      Japan1GothicBBB = "Japan1GothicBBB", Japan1Ryumin = "Japan1Ryumin",
+      Korea1 = "Korea1", Korea1deb = "Korea1deb", CNS1 = "CNS1", GB1 = "GB1"
+      )
+  }
+    
   plugins <- Rcmdr$plugins
   if (!pkgname %in% plugins) {
     Rcmdr$plugins <- c(plugins, pkgname)
